@@ -27,8 +27,8 @@ func TestIntegratedDashboardService(t *testing.T) {
 				return nil
 			})
 
-			bus.AddHandler("test", func(cmd *models.IsDashboardProvisionedQuery) error {
-				cmd.Result = false
+			bus.AddHandler("test", func(cmd *models.GetProvisionedDashboardDataByIdQuery) error {
+				cmd.Result = nil
 				return nil
 			})
 
@@ -129,7 +129,6 @@ func TestIntegratedDashboardService(t *testing.T) {
 			// Given user has no permission to save
 
 			permissionScenario("Given user has no permission to save", false, func(sc *dashboardPermissionScenarioContext) {
-
 				Convey("When creating a new dashboard in the General folder", func() {
 					cmd := models.SaveDashboardCommand{
 						OrgId: testOrgId,
@@ -370,7 +369,6 @@ func TestIntegratedDashboardService(t *testing.T) {
 			// Given user has permission to save
 
 			permissionScenario("Given user has permission to save", true, func(sc *dashboardPermissionScenarioContext) {
-
 				Convey("and overwrite flag is set to false", func() {
 					shouldOverwrite := false
 
@@ -964,13 +962,13 @@ func permissionScenario(desc string, canSave bool, fn dashboardPermissionScenari
 
 func callSaveWithResult(cmd models.SaveDashboardCommand) *models.Dashboard {
 	dto := toSaveDashboardDto(cmd)
-	res, _ := dashboards.NewService().SaveDashboard(&dto)
+	res, _ := dashboards.NewService().SaveDashboard(&dto, false)
 	return res
 }
 
 func callSaveWithError(cmd models.SaveDashboardCommand) error {
 	dto := toSaveDashboardDto(cmd)
-	_, err := dashboards.NewService().SaveDashboard(&dto)
+	_, err := dashboards.NewService().SaveDashboard(&dto, false)
 	return err
 }
 
@@ -994,7 +992,7 @@ func saveTestDashboard(title string, orgId int64, folderId int64) *models.Dashbo
 		},
 	}
 
-	res, err := dashboards.NewService().SaveDashboard(&dto)
+	res, err := dashboards.NewService().SaveDashboard(&dto, false)
 	So(err, ShouldBeNil)
 
 	return res
@@ -1020,7 +1018,7 @@ func saveTestFolder(title string, orgId int64) *models.Dashboard {
 		},
 	}
 
-	res, err := dashboards.NewService().SaveDashboard(&dto)
+	res, err := dashboards.NewService().SaveDashboard(&dto, false)
 	So(err, ShouldBeNil)
 
 	return res
