@@ -1,2 +1,2 @@
-import { MixedDatasource } from './datasource';
+import { MixedDatasource } from './MixedDataSource';
 export { MixedDatasource, MixedDatasource as Datasource };
