@@ -17,7 +17,7 @@ post_data=$(cat <<EOF
 EOF
 )
 
-echo ${post_data}
+echo "${post_data}"
 
 curl \
 --header "Accept: application/json" \
